@@ -1,6 +1,6 @@
 /* Declarations for command data.
  *
- * (C) 2003-2016 Anope Team
+ * (C) 2003-2017 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -59,6 +59,8 @@ class CoreExport CommandSource
  public:
 	/* The account executing the command */
 	Reference<NickCore> nc;
+	/* for web clients */
+	Anope::string ip;
 	/* Where the reply should go */
 	CommandReply *reply;
 	/* Channel the command was executed on (fantasy) */
