@@ -1,6 +1,6 @@
 /* Modular support
  *
- * (C) 2003-2016 Anope Team
+ * (C) 2003-2017 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -72,7 +72,7 @@
 /**
  * This #define allows us to call a method in all
  * loaded modules in a readable simple way, e.g.:
- * 
+ *
  * FOREACH_MOD(OnUserConnect, (user, exempt));
  */
 #define FOREACH_MOD(ename, args) \
@@ -104,7 +104,7 @@ else \
  * This define is similar to the one above but returns a result.
  * The first module to return a result other than EVENT_CONTINUE is the value to be accepted,
  * and any modules after are ignored. This is used like:
- * 
+ *
  * EventReturn MOD_RESULT;
  * FOREACH_RESULT(OnUserConnect, MOD_RESULT, (user, exempt));
  */
@@ -301,6 +301,11 @@ class CoreExport Module : public Extensible
 	 * before they will be called.
 	 */
 
+	/** Called on startup after database load, but before
+	 * connecting to the uplink.
+	 */
+	virtual void OnPostInit() { throw NotImplementedException(); }
+
 	/** Called before a user has been kicked from a channel.
 	 * @param source The kicker
 	 * @param cu The user, channel, and status of the user being kicked
@@ -1099,6 +1104,7 @@ class CoreExport Module : public Extensible
 
 enum Implementation
 {
+	I_OnPostInit,
 	I_OnPreUserKicked, I_OnUserKicked, I_OnReload, I_OnPreBotAssign, I_OnBotAssign, I_OnBotUnAssign, I_OnUserConnect,
 	I_OnNewServer, I_OnUserNickChange, I_OnPreHelp, I_OnPostHelp, I_OnPreCommand, I_OnPostCommand, I_OnSaveDatabase,
 	I_OnLoadDatabase, I_OnEncrypt, I_OnDecrypt, I_OnBotFantasy, I_OnBotNoFantasyAccess, I_OnBotBan, I_OnBadWordAdd,
