@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2012-2016 Anope Team
+ * (C) 2012-2017 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -228,6 +228,9 @@ namespace HTTPUtils
 				case '"':
 					dst += "&quot;";
 					break;
+				case '&':
+					dst += "&amp;";
+					break;
 				default:
 					dst += src[i];
 			}
