@@ -1,6 +1,6 @@
 /* BotServ core functions
  *
- * (C) 2003-2016 Anope Team
+ * (C) 2003-2017 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -114,7 +114,7 @@ class CommandBSSetBanExpire : public Command
 		}
 
 		time_t t = Anope::DoTime(arg);
-		if (t == -1)
+		if (t < 0)
 		{
 			source.Reply(BAD_EXPIRY_TIME);
 			return;
