@@ -1,6 +1,6 @@
 /* ChanServ core functions
  *
- * (C) 2003-2016 Anope Team
+ * (C) 2003-2017 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -113,10 +113,6 @@ class CommandCSXOP : public Command
 			return;
 		}
 
-		XOPChanAccess tmp_access(NULL);
-		tmp_access.ci = ci;
-		tmp_access.type = source.command.upper();
-
 		AccessGroup access = source.AccessFor(ci);
 		const ChanAccess *highest = access.Highest();
 		bool override = false;
@@ -246,10 +242,6 @@ class CommandCSXOP : public Command
 			return;
 		}
 
-		XOPChanAccess tmp_access(NULL);
-		tmp_access.ci = ci;
-		tmp_access.type = source.command.upper();
-
 		AccessGroup access = source.AccessFor(ci);
 		const ChanAccess *highest = access.Highest();
 		bool override = false;
@@ -357,7 +349,7 @@ class CommandCSXOP : public Command
 					return;
 				}
 			}
-			
+
 			source.Reply(_("\002%s\002 not found on %s %s list."), mask.c_str(), ci->name.c_str(), source.command.c_str());
 		}
 	}
@@ -474,7 +466,7 @@ class CommandCSXOP : public Command
 
 			if (access->provider->name != "access/xop" || source.command.upper() != access->AccessSerialize())
 				continue;
-	
+
 			delete ci->EraseAccess(i - 1);
 		}
 
@@ -569,7 +561,7 @@ class CommandCSXOP : public Command
 		BotInfo *access_bi, *flags_bi;
 		Anope::string access_cmd, flags_cmd;
 		Command::FindCommandFromService("chanserv/access", access_bi, access_cmd);
-		Command::FindCommandFromService("chanserv/flags", flags_bi, access_cmd);
+		Command::FindCommandFromService("chanserv/flags", flags_bi, flags_cmd);
 		if (!access_cmd.empty() || !flags_cmd.empty())
 		{
 			source.Reply(_("Alternative methods of modifying channel access lists are\n"
