@@ -1,6 +1,6 @@
 /* ChanServ core functions
  *
- * (C) 2003-2016 Anope Team
+ * (C) 2003-2017 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -377,40 +377,42 @@ class ChanServCore : public Module, public ChanServService
 		return EVENT_CONTINUE;
 	}
 
-	void OnPreUplinkSync(Server *serv) anope_override
+	void OnPostInit() anope_override
 	{
 		if (!persist)
 			return;
+
+		ChannelMode *perm = ModeManager::FindChannelModeByName("PERM");
+
 		/* Find all persistent channels and create them, as we are about to finish burst to our uplink */
 		for (registered_channel_map::iterator it = RegisteredChannelList->begin(), it_end = RegisteredChannelList->end(); it != it_end; ++it)
 		{
 			ChannelInfo *ci = it->second;
-			if (persist->HasExt(ci))
-			{
-				bool c;
-				ci->c = Channel::FindOrCreate(ci->name, c, ci->time_registered);
+			if (!persist->HasExt(ci))
+				continue;
 
-				if (ModeManager::FindChannelModeByName("PERM") != NULL)
+			bool c;
+			ci->c = Channel::FindOrCreate(ci->name, c, ci->time_registered);
+			ci->c->syncing |= created;
+
+			if (perm)
+			{
+				ci->c->SetMode(NULL, perm);
+			}
+			else
+			{
+				if (!ci->bi)
+					ci->WhoSends()->Assign(NULL, ci);
+				if (ci->c->FindUser(ci->bi) == NULL)
 				{
-					if (c)
-						IRCD->SendChannel(ci->c);
-					ci->c->SetMode(NULL, "PERM");
-				}
-				else
-				{
-					if (!ci->bi)
-						ci->WhoSends()->Assign(NULL, ci);
-					if (ci->c->FindUser(ci->bi) == NULL)
-					{
-						ChannelStatus status(BotModes());
-						ci->bi->Join(ci->c, &status);
-					}
+					ChannelStatus status(BotModes());
+					ci->bi->Join(ci->c, &status);
 				}
 			}
 		}
 
 	}
-	
+
 	void OnChanRegistered(ChannelInfo *ci) anope_override
 	{
 		if (!persist || !ci->c)
@@ -476,4 +478,3 @@ class ChanServCore : public Module, public ChanServService
 };
 
 MODULE_INIT(ChanServCore)
-
