@@ -1,6 +1,6 @@
 /* NickServ core functions
  *
- * (C) 2003-2016 Anope Team
+ * (C) 2003-2017 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -493,13 +493,6 @@ class NickServCore : public Module, public NickServService
 				"Accounts that are not used anymore are subject to\n"
 				"the automatic expiration, i.e. they will be deleted\n"
 				"after %d days if not used."), nickserv_expire / 86400);
-		source.Reply(_(" \n"
-			"\002NOTICE:\002 This service is intended to provide a way for\n"
-			"IRC users to ensure their identity is not compromised.\n"
-			"It is \002NOT\002 intended to facilitate \"stealing\" of\n"
-			"nicknames or other malicious actions. Abuse of %s\n"
-			"will result in, at minimum, loss of the abused\n"
-			"nickname(s)."), NickServ->nick.c_str());
 	}
 
 	void OnNickCoreCreate(NickCore *nc)
@@ -545,7 +538,7 @@ class NickServCore : public Module, public NickServService
 				expire = true;
 
 			FOREACH_MOD(OnPreNickExpire, (na, expire));
-		
+
 			if (expire)
 			{
 				Log(LOG_NORMAL, "nickserv/expire", NickServ) << "Expiring nickname " << na->nick << " (group: " << na->nc->display << ") (e-mail: " << (na->nc->email.empty() ? "none" : na->nc->email) << ")";
@@ -572,4 +565,3 @@ class NickServCore : public Module, public NickServService
 };
 
 MODULE_INIT(NickServCore)
-
