@@ -1,5 +1,5 @@
 /*
- * (C) 2003-2016 Anope Team
+ * (C) 2003-2017 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -102,7 +102,7 @@ bool WebCPanel::ChanServ::Set::OnRequest(HTTPProvider *server, const Anope::stri
 		}
 	}
 
-	replacements["CHANNEL"] = HTTPUtils::Escape(ci->name);
+	replacements["CHANNEL"] = ci->name;
 	replacements["CHANNEL_ESCAPED"] = HTTPUtils::URLEncode(ci->name);
 	if (ci->GetFounder())
 		replacements["FOUNDER"] = ci->GetFounder()->display;
@@ -114,8 +114,8 @@ bool WebCPanel::ChanServ::Set::OnRequest(HTTPProvider *server, const Anope::stri
 
 	if (!ci->last_topic.empty())
 	{
-		replacements["LAST_TOPIC"] = HTTPUtils::Escape(ci->last_topic);
-		replacements["LAST_TOPIC_SETTER"] = HTTPUtils::Escape(ci->last_topic_setter);
+		replacements["LAST_TOPIC"] = ci->last_topic;
+		replacements["LAST_TOPIC_SETTER"] = ci->last_topic_setter;
 	}
 
 	if (can_set)
@@ -152,4 +152,3 @@ std::set<Anope::string> WebCPanel::ChanServ::Set::GetData()
 	v.insert("channel");
 	return v;
 }
-
