@@ -1,5 +1,5 @@
 /*
- * (C) 2003-2016 Anope Team
+ * (C) 2003-2017 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -12,11 +12,15 @@ namespace WebCPanel
 
 class Index : public WebPanelPage
 {
+	static const int FLUSH_TIME = 60;
+
+	Anope::hash_map<time_t> last_login_attempt;
+	time_t last_clear;
+
  public:
-	Index(const Anope::string &u) : WebPanelPage(u) { }
+	Index(const Anope::string &u) : WebPanelPage(u), last_clear(0) { }
 
 	bool OnRequest(HTTPProvider *, const Anope::string &, HTTPClient *, HTTPMessage &, HTTPReply &) anope_override;
 };
 
 }
-
