@@ -1,5 +1,5 @@
 /*
- * (C) 2003-2016 Anope Team
+ * (C) 2003-2017 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -72,7 +72,7 @@ bool WebCPanel::NickServ::Info::OnRequest(HTTPProvider *server, const Anope::str
 		}
 		else if (message.post_data["kill"] == "quick" && !na->nc->HasExt("KILL_QUICK"))
 		{
-			na->nc->Shrink<bool>("KILLPROTECT");
+			na->nc->Extend<bool>("KILLPROTECT");
 			na->nc->Extend<bool>("KILL_QUICK");
 			replacements["MESSAGES"] = "Kill updated";
 		}
@@ -84,9 +84,9 @@ bool WebCPanel::NickServ::Info::OnRequest(HTTPProvider *server, const Anope::str
 		}
 	}
 
-	replacements["DISPLAY"] = HTTPUtils::Escape(na->nc->display);
+	replacements["DISPLAY"] = na->nc->display;
 	if (na->nc->email.empty() == false)
-		replacements["EMAIL"] = HTTPUtils::Escape(na->nc->email);
+		replacements["EMAIL"] = na->nc->email;
 	replacements["TIME_REGISTERED"] = Anope::strftime(na->time_registered, na->nc);
 	if (na->HasVhost())
 	{
@@ -97,7 +97,7 @@ bool WebCPanel::NickServ::Info::OnRequest(HTTPProvider *server, const Anope::str
 	}
 	Anope::string *greet = na->nc->GetExt<Anope::string>("greet");
 	if (greet)
-		replacements["GREET"] = HTTPUtils::Escape(*greet);
+		replacements["GREET"] = *greet;
 	if (na->nc->HasExt("AUTOOP"))
 		replacements["AUTOOP"];
 	if (na->nc->HasExt("NS_PRIVATE"))
@@ -110,9 +110,8 @@ bool WebCPanel::NickServ::Info::OnRequest(HTTPProvider *server, const Anope::str
 		replacements["KILL_QUICK"];
 	if (!na->nc->HasExt("KILLPROTECT") && !na->nc->HasExt("KILL_QUICK"))
 		replacements["KILL_OFF"];
-	
+
 	TemplateFileServer page("nickserv/info.html");
 	page.Serve(server, page_name, client, message, reply, replacements);
 	return true;
 }
-
