@@ -1,5 +1,5 @@
 /*
- * (C) 2003-2016 Anope Team
+ * (C) 2003-2017 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -79,7 +79,7 @@ static Anope::string FindReplacement(const TemplateFileServer::Replacements &r,
 			}
 		}
 	}
-	
+
 	TemplateFileServer::Replacements::const_iterator it = r.find(key);
 	if (it != r.end())
 		return it->second;
@@ -110,7 +110,7 @@ void TemplateFileServer::Serve(HTTPProvider *server, const Anope::string &page_n
 		buffer[i] = 0;
 		buf += buffer;
 	}
-	
+
 	close(fd);
 
 	Anope::string finished;
@@ -235,10 +235,14 @@ void TemplateFileServer::Serve(HTTPProvider *server, const Anope::string &page_n
 				// If the if stack is empty or we are in a true statement
 				bool ifok = IfStack.empty() || IfStack.top();
 				bool forok = ForLoop::Stack.empty() || !ForLoop::Stack.back().finished(r);
-			
+
 				if (ifok && forok)
 				{
-					const Anope::string &replacement = FindReplacement(r, content.substr(0, f - 1));
+					Anope::string replacement = FindReplacement(r, content.substr(0, f - 1));
+
+					// htmlescape all text replaced onto the page
+					replacement = HTTPUtils::Escape(replacement);
+
 					finished += replacement;
 				}
 			}
@@ -252,7 +256,7 @@ void TemplateFileServer::Serve(HTTPProvider *server, const Anope::string &page_n
 			// If the if stack is empty or we are in a true statement
 			bool ifok = IfStack.empty() || IfStack.top();
 			bool forok = ForLoop::Stack.empty() || !ForLoop::Stack.back().finished(r);
-			
+
 			if (ifok && forok)
 				finished += buf[j];
 		}
@@ -261,4 +265,3 @@ void TemplateFileServer::Serve(HTTPProvider *server, const Anope::string &page_n
 	if (!finished.empty())
 		reply.Write(finished);
 }
-
