@@ -1,6 +1,6 @@
 /* smtp stuff handler for win32.
  *
- * (C) 2003-2016 Anope Team
+ * (C) 2003-2017 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -107,6 +107,18 @@ static std::string get_logname(struct tm *tm = NULL)
 	return name;
 }
 
+/* TimeStamp for Email Header */
+static std::string GetTimeStamp()
+{
+	char tbuf[256];
+	time_t t = time(NULL);
+	struct tm *tm = localtime(&t);
+
+	strftime(tbuf, sizeof(tbuf) - 1, "%a, %d %b %Y %H:%M:%S %z", tm);
+
+	return tbuf;
+}
+
 /* Log stuff to the log file with a datestamp.  Note that errno is
  * preserved by this routine and log_perror().
  */
@@ -288,7 +300,7 @@ int smtp_send_email()
 
 	if (!smtp_send("HELO anope\r\n"))
 	{
-		alog("SMTP: error writting to socket");
+		alog("SMTP: error writing to socket");
 		return 0;
 	}
 
@@ -311,7 +323,7 @@ int smtp_send_email()
 
 	if (!smtp_send(buf))
 	{
-		alog("SMTP: error writting to socket");
+		alog("SMTP: error writing to socket");
 		return 0;
 	}
 
@@ -331,7 +343,7 @@ int smtp_send_email()
 
 	if (!smtp_send(buf))
 	{
-		alog("SMTP: error writting to socket");
+		alog("SMTP: error writing to socket");
 		return 0;
 	}
 
@@ -350,7 +362,7 @@ int smtp_send_email()
 
 	if (!smtp_send("DATA\r\n"))
 	{
-		alog("SMTP: error writting to socket");
+		alog("SMTP: error writing to socket");
 		return 0;
 	}
 
@@ -370,13 +382,13 @@ int smtp_send_email()
 	for (std::vector<std::string>::const_iterator it = smail.smtp_headers.begin(), it_end = smail.smtp_headers.end(); it != it_end; ++it)
 		if (!smtp_send(it->c_str()))
 		{
-			alog("SMTP: error writting to socket");
+			alog("SMTP: error writing to socket");
 			return 0;
 		}
 
 	if (!smtp_send("\r\n"))
 	{
-		alog("SMTP: error writting to socket");
+		alog("SMTP: error writing to socket");
 		return 0;
 	}
 
@@ -386,7 +398,7 @@ int smtp_send_email()
 		{
 			if (!smtp_send(it->c_str()))
 			{
-				alog("SMTP: error writting to socket");
+				alog("SMTP: error writing to socket");
 				return 0;
 			}
 		}
@@ -395,7 +407,7 @@ int smtp_send_email()
 
 	if (!smtp_send("\r\n.\r\n"))
 	{
-		alog("SMTP: error writting to socket");
+		alog("SMTP: error writing to socket");
 		return 0;
 	}
 
@@ -417,7 +429,7 @@ int main(int argc, char *argv[])
 
 	if (argc == 1)
 		return 0;
-	
+
 	if (argc == 3 && !strcmp(argv[2], "--debug"))
 		smtp_debug = 1;
 
@@ -468,6 +480,7 @@ int main(int argc, char *argv[])
 				break;
 			else
 			{
+				smail.smtp_headers.push_back("Date: " + GetTimeStamp() + "\r\n");
 				headers_done = true;
 				smail.smtp_body.push_back(strip(buf) + "\r\n");
 			}
